@@ -39,7 +39,7 @@
 #include <iostream>
 
 bool ClientApp::m_ok = true;
-static bool s_interactive = true;
+static bool s_interactive = false;
 static KIO::JobFlags s_jobFlags = KIO::DefaultFlags;
 
 static QUrl makeURL(const QString &urlArg)
@@ -59,51 +59,51 @@ static QList<QUrl> makeUrls(const QStringList& urlArgs)
 #ifdef KIOCLIENT_AS_KIOCLIENT5
 static void usage()
 {
-    puts(i18n("\nSyntax:\n").toLocal8Bit());
+    puts(i18n("\nSyntax:\n").toLocal8Bit().constData());
     puts(i18n("  kioclient openProperties 'url'\n"
-              "            # Opens a properties menu\n\n").toLocal8Bit());
+              "            # Opens a properties menu\n\n").toLocal8Bit().constData());
     puts(i18n("  kioclient exec 'url' ['mimetype']\n"
               "            # Tries to open the document pointed to by 'url', in the application\n"
               "            #   associated with it in KDE. You may omit 'mimetype'.\n"
               "            #   In this case the mimetype is determined\n"
               "            #   automatically. Of course URL may be the URL of a\n"
               "            #   document, or it may be a *.desktop file.\n"
-              "            #   'url' can be an executable, too.\n").toLocal8Bit());
+              "            #   'url' can be an executable, too.\n").toLocal8Bit().constData());
     puts(i18n("  kioclient move 'src' 'dest'\n"
               "            # Moves the URL 'src' to 'dest'.\n"
-              "            #   'src' may be a list of URLs.\n").toLocal8Bit());
+              "            #   'src' may be a list of URLs.\n").toLocal8Bit().constData());
     puts(i18n("            #   'dest' may be \"trash:/\" to move the files\n"
-              "            #   to the trash.\n").toLocal8Bit());
+              "            #   to the trash.\n").toLocal8Bit().constData());
     puts(i18n("            #   the short version kioclient mv\n"
-              "            #   is also available.\n\n").toLocal8Bit());
+              "            #   is also available.\n\n").toLocal8Bit().constData());
     puts(i18n("  kioclient download ['src']\n"
               "            # Copies the URL 'src' to a user-specified location'.\n"
               "            #   'src' may be a list of URLs, if not present then\n"
-              "            #   a URL will be requested.\n\n").toLocal8Bit());
+              "            #   a URL will be requested.\n\n").toLocal8Bit().constData());
     puts(i18n("  kioclient copy 'src' 'dest'\n"
               "            # Copies the URL 'src' to 'dest'.\n"
-              "            #   'src' may be a list of URLs.\n").toLocal8Bit());
+              "            #   'src' may be a list of URLs.\n").toLocal8Bit().constData());
     puts(i18n("            #   the short version kioclient cp\n"
-              "            #   is also available.\n\n").toLocal8Bit());
+              "            #   is also available.\n\n").toLocal8Bit().constData());
     puts(i18n("  kioclient cat 'url'\n"
-              "            # Writes out the contents of 'url' to stdout\n\n").toLocal8Bit());
+              "            # Writes out the contents of 'url' to stdout\n\n").toLocal8Bit().constData());
     puts(i18n("  kioclient ls 'url'\n"
-              "            # Lists the contents of the directory 'url' to stdout\n\n").toLocal8Bit());
+              "            # Lists the contents of the directory 'url' to stdout\n\n").toLocal8Bit().constData());
     puts(i18n("  kioclient remove 'url'\n"
               "            # Removes the URL\n"
-              "            #   'url' may be a list of URLs.\n").toLocal8Bit());
+              "            #   'url' may be a list of URLs.\n").toLocal8Bit().constData());
     puts(i18n("            #   the short version kioclient rm\n"
-              "            #   is also available.\n\n").toLocal8Bit());
+              "            #   is also available.\n\n").toLocal8Bit().constData());
 
-    puts(i18n("*** Examples:\n").toLocal8Bit());
+    puts(i18n("*** Examples:\n").toLocal8Bit().constData());
     puts(i18n("  kioclient exec file:/home/weis/data/test.html\n"
-              "             // Opens the file with default binding\n\n").toLocal8Bit());
+              "             // Opens the file with default binding\n\n").toLocal8Bit().constData());
     puts(i18n("  kioclient exec ftp://localhost/\n"
-              "             // Opens new window with URL\n\n").toLocal8Bit());
+              "             // Opens new window with URL\n\n").toLocal8Bit().constData());
     puts(i18n("  kioclient exec file:/root/Desktop/emacs.desktop\n"
-              "             // Starts emacs\n\n").toLocal8Bit());
+              "             // Starts emacs\n\n").toLocal8Bit().constData());
     puts(i18n("  kioclient exec .\n"
-              "             // Opens the current directory. Very convenient.\n\n").toLocal8Bit());
+              "             // Opens the current directory. Very convenient.\n\n").toLocal8Bit().constData());
 }
 #endif
 
@@ -126,6 +126,8 @@ int main( int argc, char **argv )
 
   QCommandLineParser parser;
   data.setupCommandLine(&parser);
+  parser.addOption(QCommandLineOption(QStringLiteral("interactive"), i18n("Use message boxes and other native notifications")));
+
   parser.addOption(QCommandLineOption(QStringLiteral("noninteractive"), i18n("Non-interactive use: no message boxes. If you don't want a "
                                                              "graphical connection, use --platform offscreen")));
 
@@ -155,7 +157,7 @@ int main( int argc, char **argv )
 #ifdef KIOCLIENT_AS_KIOCLIENT5
   if ( argc == 1 || parser.isSet(QStringLiteral("commands")) )
   {
-    puts(parser.helpText().toLocal8Bit());
+    puts(parser.helpText().toLocal8Bit().constData());
     puts("\n\n");
     usage();
     return 0;
@@ -181,12 +183,12 @@ static void checkArgumentCount(int count, int min, int max)
 {
     if (count < min)
     {
-        fputs( i18nc("@info:shell", "%1: Syntax error, not enough arguments\n", qAppName()).toLocal8Bit(), stderr );
+        fputs( i18nc("@info:shell", "%1: Syntax error, not enough arguments\n", qAppName()).toLocal8Bit().constData(), stderr );
         ::exit(1);
     }
     if (max && (count > max))
     {
-        fputs( i18nc("@info:shell", "%1: Syntax error, too many arguments\n", qAppName()).toLocal8Bit(), stderr );
+        fputs( i18nc("@info:shell", "%1: Syntax error, too many arguments\n", qAppName()).toLocal8Bit().constData(), stderr );
         ::exit(1);
     }
 }
@@ -212,8 +214,10 @@ bool ClientApp::doCopy( const QStringList& urls )
     QList<QUrl> srcLst(makeUrls(urls));
     QUrl dest = srcLst.takeLast();
     KIO::Job * job = KIO::copy( srcLst, dest, s_jobFlags );
-    if ( !s_interactive )
+    if ( !s_interactive ) {
         job->setUiDelegate( nullptr );
+        job->setUiDelegateExtension( nullptr );
+    }
     connect( job, SIGNAL( result( KJob * ) ), this, SLOT( slotResult( KJob * ) ) );
     qApp->exec();
     return m_ok;
@@ -233,8 +237,10 @@ bool ClientApp::doList( const QStringList& urls )
 {
     QUrl dir = makeURL(urls.first());
     KIO::Job * job = KIO::listDir(dir, KIO::HideProgressInfo);
-    if ( !s_interactive )
-        job->setUiDelegate(nullptr);
+    if ( !s_interactive ) {
+        job->setUiDelegate( nullptr );
+        job->setUiDelegateExtension( nullptr );
+    }
     connect(job, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
             SLOT(slotEntries(KIO::Job*,KIO::UDSEntryList)));
     connect(job, SIGNAL(result(KJob *)), this, SLOT(slotResult(KJob *)));
@@ -247,8 +253,10 @@ bool ClientApp::doMove( const QStringList& urls )
     QList<QUrl> srcLst(makeUrls(urls));
     QUrl dest = srcLst.takeLast();
     KIO::Job * job = KIO::move( srcLst, dest, s_jobFlags );
-    if ( !s_interactive )
+    if ( !s_interactive ) {
         job->setUiDelegate( nullptr );
+        job->setUiDelegateExtension( nullptr );
+    }
     connect( job, SIGNAL( result( KJob * ) ), this, SLOT( slotResult( KJob * ) ) );
     qApp->exec();
     return m_ok;
@@ -257,8 +265,10 @@ bool ClientApp::doMove( const QStringList& urls )
 bool ClientApp::doRemove( const QStringList& urls )
 {
     KIO::Job * job = KIO::del( makeUrls(urls), s_jobFlags );
-    if ( !s_interactive )
+    if ( !s_interactive ) {
         job->setUiDelegate( nullptr );
+        job->setUiDelegateExtension( nullptr );
+    }
     connect( job, SIGNAL( result( KJob * ) ), this, SLOT( slotResult( KJob * ) ) );
     qApp->exec();
     return m_ok;
@@ -269,7 +279,11 @@ bool ClientApp::doIt(const QCommandLineParser& parser)
     const int argc = parser.positionalArguments().count();
     checkArgumentCount(argc, 1, 0);
 
-    if ( !parser.isSet( QStringLiteral("noninteractive") ) ) {
+    if (parser.isSet(QStringLiteral("interactive"))) {
+        s_interactive = true;
+    } else {
+        // "noninteractive" is currently the default mode, so we don't check.
+        // The argument still needs to exist for compatibility
         s_interactive = false;
         s_jobFlags = KIO::HideProgressInfo;
     }
@@ -309,8 +323,10 @@ bool ClientApp::doIt(const QCommandLineParser& parser)
         checkArgumentCount(argc, 2, 2); // cat <url>
         QUrl url = makeURL(parser.positionalArguments().last());
         KIO::TransferJob* job = KIO::get(url, KIO::NoReload, s_jobFlags);
-        if ( !s_interactive )
+        if ( !s_interactive ) {
             job->setUiDelegate( nullptr );
+            job->setUiDelegateExtension( nullptr );
+        }
         connect(job, SIGNAL(data(KIO::Job*,QByteArray) ), this, SLOT(slotPrintData(KIO::Job*,QByteArray)));
         connect(job, SIGNAL( result( KJob * ) ), this, SLOT( slotResult( KJob * ) ) );
         qApp->exec();
@@ -339,8 +355,10 @@ bool ClientApp::doIt(const QCommandLineParser& parser)
         if (dsturl.isEmpty()) // canceled
             return m_ok; // AK - really okay?
         KIO::Job * job = KIO::copy( srcLst, dsturl, s_jobFlags );
-        if ( !s_interactive )
+        if ( !s_interactive ) {
             job->setUiDelegate( nullptr );
+            job->setUiDelegateExtension( nullptr );
+        }
         connect( job, SIGNAL( result( KJob * ) ), qApp, SLOT( slotResult( KJob * ) ) );
         qApp->exec();
         return m_ok;
@@ -396,7 +414,11 @@ void ClientApp::slotResult( KJob * job )
         }
     }
     m_ok = !job->error();
-    qApp->quit();
+    if (qApp->topLevelWindows().isEmpty()) {
+        qApp->quit();
+    } else {
+        qApp->setQuitOnLastWindowClosed(true);
+    }
 }
 
 void ClientApp::slotDialogCanceled()
